@@ -12,11 +12,12 @@
 (load-from-library "explode.scm")
 (load-from-library "filter.scm")
 (load-from-library "flatten.scm")
-(load-from-library "group-list.scm")
+(load-from-library "group.scm")
 (load-from-library "implode.scm")
 (load-from-library "iota.scm")
 (load-from-library "memp.scm")
 (load-from-library "listq.scm")
+(load-from-library "list-copy.scm")
 (load-from-library "partition.scm")
 (load-from-library "permute.scm")
 (load-from-library "position.scm")
@@ -25,5 +26,6 @@
 (load-from-library "sort.scm")
 (load-from-library "sublist.scm")
 (load-from-library "substitute.scm")
+(load-from-library "take.scm")
 (load-from-library "transpose.scm")
 (load-from-library "unsort.scm")
